docs.rs failed to build rustvello-0.1.4
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build:
rustvello-0.1.6
Rustvello — A distributed task library for Rust.
Rustvello provides a framework for defining, routing, and executing distributed tasks, inspired by the pynenc Python library.
Quick Start
use *;
async